@@ -1,9 +1,8 @@
-from ezcode.array.matrix import init_matrix
 
 
 def longest_common_subsequence(array_1: list, array_2: list) -> list:
     row_len, col_len = len(array_1) + 1, len(array_2) + 1  # Add one dummy row and one dummy column
-    dp = init_matrix(row=row_len, col=col_len, init=0)
+    dp = [[0 for _ in range(col_len)] for _ in range(row_len)]
     for row in range(1, row_len):
         for col in range(1, col_len):
             dp[row][col] = dp[row - 1][col - 1] + 1 if array_1[row - 1] == array_2[col - 1] else max(dp[row - 1][col], dp[row][col - 1])
@@ -19,7 +18,7 @@ def longest_common_subsequence(array_1: list, array_2: list) -> list:
 
 def longest_common_subarray(array_1: list, array_2: list) -> list:
     row_len, col_len = len(array_1) + 1, len(array_2) + 1  # Add one dummy row and one dummy column
-    dp = init_matrix(row=row_len, col=col_len, init=0)
+    dp = [[0 for _ in range(col_len)] for _ in range(row_len)]
     lcs_size, row_end = 0, 0
     for row in range(1, row_len):
         for col in range(1, col_len):
